{% load i18n adminmedia admin_modify %}
<div class="inline-group" id="{{ inline_admin_formset.formset.prefix }}-group">
  <div class="tabular inline-related {% if forloop.last %}last-related{% endif %}">
	{{ inline_admin_formset.formset.management_form }}
<fieldset class="module">
   <h2>{{ inline_admin_formset.opts.verbose_name_plural|capfirst }}</h2>
   {{ inline_admin_formset.formset.non_form_errors }}
	<ul>
     {% for inline_admin_form in inline_admin_formset %}
		{% for fieldset in inline_admin_form %}
          {% for line in fieldset %}
            {% for field in line %}
				{% if field.field %}
        			<li>{{ field.field }}</li>
				{% endif %}
			{% endfor %}
		{% endfor %}
	{% endfor %}
	{% endfor %}
	</ul>
</div>
</div>