<div>
	<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" style="width:300px;height:194px" id="b19276c4-2a17-2d74-3b27-594e84c17ee2" >
		<param name="movie" value="http://static.issuu.com/webembed/viewers/style1/v2/IssuuReader.swf?mode=mini&amp;embedBackground=%23ffffff&amp;shareMenuEnabled=false&amp;backgroundColor=%23222222&amp;documentId={{ documentid }}" />
		<param name="allowfullscreen" value="true"/>
		<param name="menu" value="false"/>
		<param name="wmode" value="transparent"/>
		<embed src="http://static.issuu.com/webembed/viewers/style1/v2/IssuuReader.swf" type="application/x-shockwave-flash" allowfullscreen="true" menu="false" wmode="transparent" style="width:300px;height:194px" flashvars="mode=mini&amp;embedBackground=%23ffffff&amp;shareMenuEnabled=false&amp;backgroundColor=%23222222&amp;documentId={{ documentid }}" />
	</object>
</div>
