<form action="/post/form/" method="post">
	{% csrf_token %}
	<!--
	<input type="hidden" name="_success_url" value="/message-received/" />
	<input type="hidden" name="_subject" value="Contact Form" />
	-->
	<div class="clearfix">
      <label for="frm_name">Your Name</label>
      <div class="input">
        <input type="text" size="30" name="Name" id="frm_name" class="xlarge" />
      </div>
    </div>

	<div class="clearfix">
      <label for="frm_email">Your E-mail Address</label>
      <div class="input">
        <input type="text" size="30" name="E-mail" id="frm_email" class="xlarge" />
      </div>
    </div>

	<div class="clearfix">
      <label for="frm_message">Message</label>
      <div class="input">
        <textarea rows="3" name="Message" id="frm_message" class="xxlarge"></textarea>
        <span class="help-block">
          Type your message.
        </span>
      </div>
    </div>

	<div class="actions">
      <button type="submit" class="btn primary">Send</button>&nbsp;<button class="btn" type="reset">Reset</button>
    </div>
</form>